summaryrefslogtreecommitdiff
path: root/tex/context/base/lpdf-swf.lua
diff options
context:
space:
mode:
Diffstat (limited to 'tex/context/base/lpdf-swf.lua')
-rw-r--r--tex/context/base/lpdf-swf.lua4
1 files changed, 2 insertions, 2 deletions
diff --git a/tex/context/base/lpdf-swf.lua b/tex/context/base/lpdf-swf.lua
index fc06c9699..c3e340db0 100644
--- a/tex/context/base/lpdf-swf.lua
+++ b/tex/context/base/lpdf-swf.lua
@@ -115,7 +115,7 @@ local function insertswf(spec)
end
function backends.pdf.nodeinjections.insertswf(spec)
- local annot, preview, ref = insertswf {
+ local annotation, preview, ref = insertswf {
foundname = spec.foundname,
width = spec.width,
height = spec.height,
@@ -124,6 +124,6 @@ function backends.pdf.nodeinjections.insertswf(spec)
-- controls = spec.controls,
-- label = spec.label,
}
- -- texsprint(ctxcatcodes,format("\\pdfannot width %ssp height %ssp {%s}",spec.width,spec.height,annot())) -- brrrr
+ -- texsprint(ctxcatcodes,format("\\pdfannot width %ssp height %ssp {%s}",spec.width,spec.height,annotation())) -- brrrr
node.write(pdfannotation(spec.width,spec.height,0,annotation()))
end